==> seplib-6.3.9.tar.gz: seplib-6.3.9/seplib_base/lib/util/par/status.c <==
#include <sitedef.h>
#include <stdio.h>
#if defined(HAVE_SOCKET)
#include <sys/socket.h>
#endif
                                                                                 
#include <seplib.h>
#include <superset.h>
#include <mpi_sep.h>
#include <arpa/inet.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <netinet/in.h>

#define BUFFSIZE 1024
int sep_send_msg(char *word) {
  int sock,port;
  struct sockaddr_in server;
  char buffer[BUFFSIZE];
  unsigned int echolen;
  int received = 0;
  char ipserver[1024];

  if(1!=getch("sep.master_ip","s",ipserver)
    || 1!=getch("sep.master_port","s",port))
    return(sepwarn(NOT_MET,"must provide sep.master_ip and sep.master_port \n"));

  /* Create the TCP socket */
  if ((sock = socket(PF_INET, SOCK_STREAM, IPPROTO_TCP)) < 0) {
    fprintf(stderr,"Failed to create socket \n");
    return(1);
  }
 

  /* Construct the server sockaddr_in structure */
  memset(&server, 0, sizeof(server));       /* Clear struct */
       server.sin_family = AF_INET;              /* Internet/IP */
  server.sin_addr.s_addr = inet_addr(ipserver);  /* IP address */
  server.sin_port = htons(port);       /* server port */
  /* Establish connection */
  if (connect(sock,
              (struct sockaddr *) &server,
              sizeof(server)) < 0) {
    fprintf(stderr,"Failed to connect with server");
    return(1);
  }
      

  /* Send the word to the server */
       echolen = strlen(word);
  if (send(sock, word, echolen, 0) != echolen) {
    fprintf(stderr,"Mismatch in number of sent bytes");
    return(1);
  }
 close(sock);
 return(0);
}

==> seplib-6.3.10.tar.gz: seplib-6.3.10/seplib_base/lib/util/par/status.c <==
#include <sitedef.h>
#include <stdio.h>
#if defined(HAVE_SOCKET)
#include <sys/socket.h>
#endif
                                                                                 
#include <seplib.h>
#include <superset.h>
#include <mpi_sep.h>
#include <arpa/inet.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <netinet/in.h>

#define BUFFSIZE 1024
int sep_send_msg(char *word) {
  int sock,port;
  struct sockaddr_in server;
  char buffer[BUFFSIZE];
  unsigned int echolen;
  int received = 0;
  char ipserver[1024];

  if(1!=getch("sep.master_ip","s",ipserver)
    || 1!=getch("sep.master_port","s",&port))
    return(sepwarn(NOT_MET,"must provide sep.master_ip and sep.master_port \n"));

  /* Create the TCP socket */
  if ((sock = socket(PF_INET, SOCK_STREAM, IPPROTO_TCP)) < 0) {
    fprintf(stderr,"Failed to create socket \n");
    return(1);
  }
 

  /* Construct the server sockaddr_in structure */
  memset(&server, 0, sizeof(server));       /* Clear struct */
       server.sin_family = AF_INET;              /* Internet/IP */
  server.sin_addr.s_addr = inet_addr(ipserver);  /* IP address */
  server.sin_port = htons(port);       /* server port */
  /* Establish connection */
  if (connect(sock,
              (struct sockaddr *) &server,
              sizeof(server)) < 0) {
    fprintf(stderr,"Failed to connect with server");
    return(1);
  }
      

  /* Send the word to the server */
       echolen = strlen(word);
  if (send(sock, word, echolen, 0) != echolen) {
    fprintf(stderr,"Mismatch in number of sent bytes");
    return(1);
  }
 close(sock);
 return(0);
}
